//*****************************************************
//*****************************************************
// This program solves baseline RBC model in JQ2012
// Author: Ding Dong, ding.dong@connect.ust.hk
// Last Revision: 06/08/2021
//*****************************************************
//*****************************************************

//*****************************************************
// Variables
var    
        y       
        c
        k
        inv
        b    
        n
        w         
        d
        R
        mu
        m
        z
        xi
        logy
        logc
        loginv
        logb
        logn
        logd
        logxi
        logmu;
varexo exi ez;

// Parameters
parameters pbeta palpha pdelta ptheta ptau pkappa pdss pxi prhoxi psigmaxi prhoz psigmaz;

// Parameter value
pbeta    = 0.98;  
pdelta   = 0.05;
ptheta   = 0.35;  
ptau     = 0.05;
pkappa   = 0.15;  
pxi      = 0.15;
prhoxi   = 0.90;                 % persistence of financial shock
psigmaxi = 0.01;                 % volatility of financial shock
prhoz    = 0.90;                 % persistence of tfp shock
psigmaz  = 0.01;                 % volatility of tfp shock

// Model
model;
%-----------------------------------------
% (1) HH: labor supply equation
%----------------------------------------- 
    w     = c*palpha/(1-n);
%-----------------------------------------
% (2) HH: euler equation
%----------------------------------------- 
    1/c   = pbeta*(1+ptau)*R*(1/c(+1));
%-----------------------------------------
% (3) HH: budget constraint
%----------------------------------------- 
    d     = b/R + c - w*n-b(-1);
%-----------------------------------------
% (4) Firm: labor demand equation
%----------------------------------------- 
    w     = (1-(1+2*pkappa*(d-pdss))*mu)*(1-ptheta)*y/n;
%-----------------------------------------
% (5) Firm: stochastic discount factor
%----------------------------------------- 
    m = pbeta*c(-1)/c;
%-----------------------------------------
% (6) Firm: f.o.c. w.r.t. k
%----------------------------------------- 
    1/(1+2*pkappa*(d-pdss)) - mu*xi = m(+1)*((1-pdelta+ptheta*y(+1)/k)/(1+2*pkappa*(d(+1)-pdss))-mu(+1)*ptheta*y(+1)/k);
%-----------------------------------------
% (7) Firm: f.o.c. w.r.t. b
%----------------------------------------- 
    1/(1+2*pkappa*(d-pdss)) - mu*xi = R*m(+1)/(1+2*pkappa*(d(+1)-pdss));
%-----------------------------------------
% (8) Firm: resource constraint
%----------------------------------------- 
    y = c + pkappa*(d-pdss)^2 + k -(1-pdelta)*k(-1);
%-----------------------------------------
% (9) Firm: borrowing constaint
%----------------------------------------- 
    xi*(k-b/R) = y;
%-----------------------------------------
% (10) Firm: production technology
%----------------------------------------- 
    y = z*k(-1)^ptheta*n^(1-ptheta);
%-----------------------------------------
% (11) Firm: capital law of motion
%----------------------------------------- 
    inv = k - (1-pdelta)*k(-1);
%-----------------------------------------
% (x) exogenous shock process
%----------------------------------------- 
    log(z)   = prhoz*log(z(-1))-psigmaz*ez;
    log(xi)  = (1-prhoxi)*log(pxi)+ prhoxi*log(xi(-1)) - psigmaxi*exi;
%-----------------------------------------
% (xx) log variables
%----------------------------------------- 
    logy    = log(y);
    logc    = log(c);
    loginv  = log(inv);
    logb    = log(b);
    logn    = log(n);
    logd    = log(d);
    logxi   = log(xi);
    logmu   = log(mu);
end;

// Shock
shocks;
var exi = 1;
var ez  = 1;
end;

steady;
check;

stoch_simul(order=2, nograph, irf=20);
