function [ys,params,check] = JQ_baseline_steadystate(ys,exo,M_,options_)
%%%%%%%%%%%%%%%%%%%%%%%%%
% This function is subroutine of dynare that solves steady states of RBC.
%%%%%%%%%%%%%%%%%%%%%%%%%

%% Read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = M_.param_names{ii};
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end

check = 0;

%% Enter model equations here
n        = 0.33;
z        = 1;
xi       = pxi;
m        = pbeta;
R        = 1/((1+ptau)*pbeta);
mu       = ptau/((1+ptau)*xi);
y2k      = (R-1+pdelta)/((1-mu)*ptheta);
w        = fsolve(@(w) yfun(y2k, mu, ptheta, n, z, w), 1);
y        = w*n/((1-mu)*(1-ptheta));
k        = y/y2k;
inv      = pdelta*k;
c        = y - pdelta*k;
b        = (k-y/xi)*R;
d        = b/R + c - w*n - b;
pdss     = d;
palpha   = (w/c)*(1-n);
% 
logy    = log(y);
logc    = log(c);
loginv  = log(inv);
logb    = log(b);
logn    = log(n);
logd    = log(d);
logxi   = log(xi);
logmu   = log(mu);
%% End own model equations
params=NaN(NumberOfParameters,1);
for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'params(' num2str(iter) ') = ' M_.param_names{iter} ';' ])
end

NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = M_.endo_names{ii};
  eval(['ys(' int2str(ii) ') = ' varname ';']);

end
