//Financial frictions
//From this file you can simulate independent of TFP shock and financial shock
//you can also use this file to simulate the effect if adding this two shocks simultaneously
var y c i k  n  w r vmiu b m d z vxi d_y b_y bf_y ef_y;
varexo e_z e_f;
parameters  palpha pbeta prhoz prhoxi pdelta ptheta pkappa sigma d_ss pxi ptao ; 
pbeta = 0.98;
pdelta = 0.05;
ptheta = 0.35;
pxi = 0.15;
pkappa = 0.15;
prhoz = 0.9;
prhoxi = 0.9;
sigma_z = 0.01;
sigma_f = 0.01;
ptao = 0.05;

model;
y=z*k(-1)^ptheta*n^(1-ptheta);
w/c = palpha/(1-n);
1/c = pbeta*r*(1+ptao)/c(+1);
w*n + b - b(+1)/r +d -c = 0;
z*(1-ptheta)*y/n = w/(1-vmiu*(1+2*pkappa*(d-d_ss)));
log(vxi) = (1-prhoxi)*log(pxi) + prhoxi*log(vxi(-1)) - e_f;
log(z) = prhoz*log(z(-1)) - e_z;
m = pbeta*c(-1)/c*(1+2*pkappa*(d(-1)-d_ss))/(1+2*pkappa*(d-d_ss));
m*(1-pdelta+(1-vmiu*(1+2*pkappa*(d-d_ss)))*ptheta*y/k(-1))+vxi(-1)*vmiu(-1)*(1+2*pkappa*(d(-1)-d_ss))=1;
r*m+vxi*vmiu*(1+2*pkappa*(d-d_ss))=1;
(1-pdelta)*k(-1)+y-w*n-b+b(+1)/r-k-(d+pkappa*(d-d_ss)^2)=0;
y=c+i;
vxi*(k-b(+1)/r)=y;
bf_y = b(+1)/y;
d_y = d/y;
b_y = b/y;
ef_y = -d_y;
end;

steady;
check;

shocks;
var e_z = sigma_z^2;
var e_f = sigma_f^2;
end;

stoch_simul(order = 1,irf=40) y n vmiu b d  d_y b_y bf_y ef_y;

// Now we simulate the response to joint shocks
//initialize IRF generation
initial_condition_states = repmat(oo_.dr.ys,1,M_.maximum_lag); % set inital value (steady-state value) for endogenous variables
shock_matrix = zeros(options_.irf,M_.exo_nbr); %create a N by M shock matrix, where N is the number of irf periods and M is the number of exogenous variables
// set combined shocks
shock_matrix(1,strmatch('e_z',M_.exo_names,'exact')) = 0.01; %set TPF shock to 1
shock_matrix(1,strmatch('e_f',M_.exo_names,'exact')) = 0.01; %set financial shock to 1
y2 = simult_(M_,options_,initial_condition_states,oo_.dr,shock_matrix,1); %use Dynare built-in funtion "simult_" to simulate
y_IRF = y2(:,M_.maximum_lag+1:end)-repmat(oo_.dr.ys,1,options_.irf); %calculate deviation from steady state

// plot simulation results
t=linspace(1,options_.irf,options_.irf)';
index = [1,5,8,13,14,15,16,17];
figure
for ii = 1:9
    subplot(3,3,ii)
    id = index(ii);
    if max(abs(y_IRF(id,:)))>1e-12 %get rid of numerical inaccuracies
        %plot(y_IRF(id,:),zeros(options_.irf,1));
        plot(t,y_IRF(id,:),'-',t,zeros(options_.irf,1),'--') ;
        xlim([1 40]);
    else
        plot(zeros(options_.irf,1));
        xlim([1 40]);
    end
    title(deblank(M_.endo_names(id,:)));
end


