function [ys,params,check] = two_steadystate(ys,exo,M_,options_)
% function [ys,params,check] = NK_baseline_steadystate(ys,exo,M_,options_)
% computes the steady state for the NK_baseline.mod and uses a numerical
% solver to do so
% Inputs: 
%   - ys        [vector] vector of initial values for the steady state of
%                   the endogenous variables
%   - exo       [vector] vector of values for the exogenous variables
%   - M_        [structure] Dynare model structure
%   - options   [structure] Dynare options structure
%
% Output: 
%   - ys        [vector] vector of steady state values for the the endogenous variables
%   - params    [vector] vector of parameter values
%   - check     [scalar] set to 0 if steady state computation worked and to
%                    1 of not (allows to impose restrictions on parameters)

%% Step 1: read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = M_.param_names{ii};
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end
% initialize indicator
check = 0;

%% Step 2: Steady-state value calculation & Parameter calibration (in this baseline RBC model, we only need to calculate steady-state value)
vxi = 0.15
z = 1
n = 0.33;
r = 1/(pbeta*(1+ptao));
m = pbeta;
vmiu = ptao/((1+ptao)*pxi);
nk_ss = (((1-vxi*vmiu)/pbeta-1+pdelta)/((1-vmiu)*ptheta*z))^(1/(1-ptheta));
w = (1-vmiu)*(1-ptheta)*nk_ss^(-ptheta);
cn_ss = ((nk_ss)^(1-ptheta)-pdelta)/nk_ss;
c = cn_ss * n;
k = n/nk_ss;
y=z*k^ptheta*n^(1-ptheta);
b = r*(-y/vxi+k);
d = c + (1/r-1)*b - w*n;
d_ss = c + (1/r-1)*b - w*n;
palpha = w*(1-n)/c;
i = pdelta*k;
d_y = d/y;
b_y = b/y;
bf_y = b/y;
ef_y = -d_y;
%% Step 3: Update parameters and variables
params=NaN(NumberOfParameters,1);    
for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'params(' num2str(iter) ') = ' M_.param_names{iter} ';' ])
end

NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = M_.endo_names{ii};
  eval(['ys(' int2str(ii) ') = ' varname ';']);
end
end